
==============================================================
sphinxgen Documentation
==============================================================

|SPHINXGEN| is used to generate files from python packages and modules found
in a specified set of directories. It is intended for generating sphinx autodoc
stub files, but can be used for other purposes. Files are generated using
`jinja`_ templates to provide maximum flexbility. You can use a set of built-in
templates, or provide your own.


Documentation Contents:
------------------------------

.. toctree::
    :maxdepth: 2

    README
    cli
    templates
    {% for package in packages %}
    {{ package.doc_name }}
    {%- endfor %}

    LICENSE


Indices and tables
--------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


Version
-------------------

This documentation is for sphinxgen |release|.


Project Resources
------------------------
* `sphinxgen project homepage (bitbucket) <https://bitbucket.org/bmearns/sphinxgen>`_
* `sphinxgen on pypi <https://pypi.python.org/pypi/sphinxgen>`_
* Online documentation:
    * `Read The Docs (.org) <http://sphinxgen.readthedocs.org/>`_
    * `Python Hosted (.org) <http://pythonhosted.org/sphinxgen/>`_
